//
//  ViewController.swift
//  swipeProject
//
//  Created by Vladislav Khambir on 4/7/17.
//  Copyright © 2017 TDSoftware. All rights reserved.
//

import SwipeCellKit
import UIKit

class TableViewController: UITableViewController {

    // MARK: - Properties
    fileprivate var testData = ["test Data 1", "test Data 2", "test Data 3"]
    
    // MARK: - Methods
    private func initCells() {
        tableView.register(SwipeTableViewCell.self, forCellReuseIdentifier: "cellID")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        initCells()
    }

}

// MARK: - SwipeTableViewCellDelegate functions
extension TableViewController: SwipeTableViewCellDelegate {
    
    func tableView(_ tableView: UITableView, editActionsForRowAt indexPath: IndexPath, for orientation: SwipeActionsOrientation) -> [SwipeAction]? {
        switch orientation {
        case .right:
            let action1 = SwipeAction(style: .default, title: nil) { (_, indexPath) in
                print("action1")
            }
            let deleteAction = SwipeAction(style: .destructive, title: nil) { action, indexPath in
                self.testData.remove(at: indexPath.row)
                print("delete")
            }
            action1.backgroundColor = .lightGray
            return [deleteAction, action1]
        case .left:
            let leftAction = SwipeAction(style: .default, title: nil) { (_, indexPath) in
                print("leftAction")
                tableView.reloadData()
            }
            leftAction.backgroundColor = .green
            return [leftAction]
        }
    }
    
    func tableView(_ tableView: UITableView, editActionsOptionsForRowAt indexPath: IndexPath, for orientation: SwipeActionsOrientation) -> SwipeTableOptions {
        var options = SwipeTableOptions()
        options.expansionStyle = (orientation == .right) ? .destructive : .fill
        options.transitionStyle = .border
        return options
    }

}



// MARK: - UITableViewDatasource functions
extension TableViewController {
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard let cell = tableView.dequeueReusableCell(withIdentifier: "cellID") as? SwipeTableViewCell else { return UITableViewCell() }
        cell.textLabel?.text = testData[indexPath.row]
        cell.delegate = self
        return cell
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return testData.count
    }
    
}
